==> mozilla-source-1.0.tar.bz2: mozilla/xpinstall/wizard/os2/uninstall/logkeys.h <==
/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/*
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is Mozilla Communicator client code,
 * released March 31, 1998.
 *
 * The Initial Developer of the Original Code is Netscape Communications
 * Corporation.  Portions created by Netscape are
 * Copyright (C) 1998 Netscape Communications Corporation. All
 * Rights Reserved.
 *
 * Contributor(s): 
 *     Sean Su <ssu@netscape.com>
 */

#ifndef _LOGKEYS_H_
#define _LOGKEYS_H_

#define KEY_DO_NOT_UNINSTALL            "(*dnu*) "
#define KEY_INSTALLING                  "installing: "
#define KEY_INSTALLING_SHARED_FILE      "installing shared file: "
#define KEY_REPLACING                   "replacing: "
#define KEY_REPLACING_SHARED_FILE       "replacing shared file: "
#define KEY_STORE_REG_STRING            "store registry value string: "
#define KEY_STORE_REG_NUMBER            "store registry value number: "
#define KEY_CREATE_REG_KEY              "create registry key: "
#define KEY_COPY_FILE                   "copy file: "
#define KEY_MOVE_FILE                   "move file: "
#define KEY_RENAME_FILE                 "rename file: "
#define KEY_CREATE_FOLDER               "create folder: "
#define KEY_RENAME_DIR                  "rename dir: "
#define KEY_WINDOWS_SHORTCUT            "windows shortcut: "
#define KEY_WINDOWS_REGISTER_SERVER     "windows register server: "

#endif

==> mozilla-source-1.4.4.tar.bz2: mozilla/xpinstall/wizard/os2/uninstall/logkeys.h <==
/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/*
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is Mozilla Communicator client code,
 * released March 31, 1998.
 *
 * The Initial Developer of the Original Code is Netscape Communications
 * Corporation.  Portions created by Netscape are
 * Copyright (C) 1998 Netscape Communications Corporation. All
 * Rights Reserved.
 *
 * Contributor(s): 
 *     Sean Su <ssu@netscape.com>
 */

#ifndef _LOGKEYS_H_
#define _LOGKEYS_H_

#define KEY_DO_NOT_UNINSTALL            "(*dnu*) "
#define KEY_INSTALLING                  "installing: "
#define KEY_INSTALLING_SHARED_FILE      "installing shared file: "
#define KEY_REPLACING                   "replacing: "
#define KEY_REPLACING_SHARED_FILE       "replacing shared file: "
#define KEY_STORE_INI_ENTRY             "store ini entry: "
#define KEY_COPY_FILE                   "copy file: "
#define KEY_MOVE_FILE                   "move file: "
#define KEY_RENAME_FILE                 "rename file: "
#define KEY_CREATE_FOLDER               "create folder: "
#define KEY_RENAME_DIR                  "rename dir: "
#define KEY_OS2_OBJECT                  "os2 object: "

#endif
